@@ -534,7 +534,7 @@ def gbq_friendly_column_name(column):
     if str.isdigit(col_name[0]):
         col_name = '_' + col_name
 
-    col_name = re.sub(r'[À-ÖØ-öø-ÿ]', '_', col_name)
+    #col_name = re.sub(r'[À-ÖØ-öø-ÿ]', '_', col_name)
     return unidecode.unidecode(re.sub(r'[^\w]', '_', col_name).replace('-','_')).replace('+','plus').replace('-','to')
 
 
